@@ -7,20 +7,21 @@ from abc import ABC
 from copy import deepcopy
 from datetime import datetime
 from pathlib import Path
-from typing import Callable, Dict, List, Optional, Union, cast
+from typing import Callable, Dict, List, Optional, Tuple, Union, cast
 from warnings import warn
 
 import torch
-from torch import Tensor
+from torch import Tensor, ones, zeros
 from torch.utils.tensorboard import SummaryWriter
 
 import sbi.inference
 from sbi.inference.posterior import NeuralPosterior
 from sbi.simulators.simutils import simulate_in_batches
 from sbi.user_input.user_input_checks import prepare_for_sbi, process_x
-from sbi.utils import get_log_root
+from sbi.utils import get_log_root, handle_invalid_x, warn_on_invalid_x
 from sbi.utils.plot import pairplot
 from sbi.utils.torchutils import configure_default_device
+from sbi.utils.sbiutils import get_data_since_round, mask_sims_from_prior
 
 
 def infer(
@@ -134,9 +135,12 @@ class NeuralInference(ABC):
             self._show_progress_bars,
         )
 
-        # Initialize roundwise (theta, x) for storage of parameters and simulations.
-        # XXX Rename self._roundwise_* or self._rounds_*
-        self._theta_bank, self._x_bank = [], []
+        # Initialize roundwise (theta, x, prior_masks) for storage of parameters,
+        # simulations and masks indicating if simulations came from prior.
+        self._theta_roundwise, self._x_roundwise, self._prior_masks = [], [], []
+
+        # Initialize list that indicates the round from which simulations were drawn.
+        self._data_round_index = []
 
         # XXX We could instantiate here the Posterior for all children. Two problems:
         #     1. We must dispatch to right PotentialProvider for mcmc based on name
@@ -152,6 +156,106 @@ class NeuralInference(ABC):
             median_observation_distances=[], epochs=[], best_validation_log_probs=[],
         )
 
+    def provide_presimulated(
+        self, theta: Tensor, x: Tensor, from_round: int = 0
+    ) -> None:
+        r"""
+        Provide external $\theta$ and $x$ to be used for training later on.
+
+        Args:
+            theta: Parameter sets used to generate presimulated data.
+            x: Simulation outputs of presimulated data.
+            from_round: Which round the data was simulated from. `from_round=0` means
+                that the data came from the first round.
+        """
+        self._append_to_data_bank(theta, x, from_round)
+
+    def _append_to_data_bank(self, theta: Tensor, x: Tensor, from_round: int) -> None:
+        r"""
+        Store data in as entries in a list for each type of variable (parameter/data).
+
+        Stores $\theta$, $x$, prior_masks (indicating if simulations are coming from the
+        prior or not) and a index indicating which round the batch of simulations came
+        from.
+
+        Args:
+            theta: Parameter sets.
+            x: Simulated data.
+            from_round: What round the $(\theta, x)$ pairs are coming from. We start
+                counting from round 0.
+        """
+
+        self._theta_roundwise.append(theta)
+        self._x_roundwise.append(x)
+        self._prior_masks.append(mask_sims_from_prior(from_round, theta.size(0)))
+        self._data_round_index.append(from_round)
+
+    def _get_from_data_bank(
+        self,
+        starting_round: int = 0,
+        exclude_invalid_x: bool = True,
+        warn_on_invalid: bool = True,
+    ) -> Tuple[Tensor, Tensor, Tensor]:
+        r"""
+        Returns all $\theta$, $x$, and prior_masks from rounds >= `starting_round`.
+
+        If requested, do not return invalid data.
+
+        Args:
+            starting_round: The earliest round to return samples from (we start counting
+                from zero).
+            exclude_invalid_x: Whether to exclude simulation outputs `x=NaN` or `x=±∞`
+                during training.
+            warn_on_invalid: Whether to give out a warning if invalid simulations were
+                found.
+
+        Returns: Parameters, simulation outputs, prior masks.
+        """
+
+        theta = get_data_since_round(
+            self._theta_roundwise, self._data_round_index, starting_round
+        )
+        x = get_data_since_round(
+            self._x_roundwise, self._data_round_index, starting_round
+        )
+        prior_masks = get_data_since_round(
+            self._prior_masks, self._data_round_index, starting_round
+        )
+
+        # Check for NaNs in simulations.
+        is_valid_x, num_nans, num_infs = handle_invalid_x(x, exclude_invalid_x)
+        if warn_on_invalid:
+            warn_on_invalid_x(num_nans, num_infs, exclude_invalid_x)
+
+        return theta[is_valid_x], x[is_valid_x], prior_masks[is_valid_x]
+
+    def _run_simulations(self, round_: int, num_sims: int,) -> Tuple[Tensor, Tensor]:
+        r"""
+        Run the simulations for a given round.
+
+        Args:
+            round_: Round number.
+            num_sims: Number of desired simulations for the round.
+
+        Returns:
+            theta: Parameters used for training.
+            x: Simulations used for training.
+            prior_mask: Whether each simulation came from a prior parameter sample.
+        """
+
+        if round_ == 0:
+            theta = self._prior.sample((num_sims,))
+        else:
+            theta = self._posterior.sample(
+                (num_sims,),
+                x=self._posterior.default_x,
+                show_progress_bars=self._show_progress_bars,
+            )
+
+        x = self._batched_simulator(theta)
+
+        return theta, x
+
     def _converged(self, epoch: int, stop_after_epochs: int) -> bool:
         """Return whether the training converged yet and save best model state so far.
 
@@ -270,8 +374,8 @@ class NeuralInference(ABC):
         self,
         round_: int,
         x_o: Union[Tensor, None],
-        theta_bank: List[Tensor],
-        x_bank: List[Tensor],
+        theta_bank: Tensor,
+        x_bank: Tensor,
         posterior_samples_acceptance_rate: Optional[Tensor] = None,
     ) -> None:
         """Update the summary_writer with statistics for a given round.
@@ -287,7 +391,7 @@ class NeuralInference(ABC):
         # Median |x - x0| for most recent round.
         if x_o is not None:
             median_observation_distance = torch.median(
-                torch.sqrt(torch.sum((x_bank[-1] - x_o.reshape(1, -1)) ** 2, dim=-1,))
+                torch.sqrt(torch.sum((x_bank - x_o.reshape(1, -1)) ** 2, dim=-1,))
             )
             self._summary["median_observation_distances"].append(
                 median_observation_distance.item()
@@ -313,7 +417,7 @@ class NeuralInference(ABC):
 
         # Plot most recently sampled parameters.
         # XXX: need more plotting kwargs, e.g., prior limits.
-        parameters = theta_bank[-1]
+        parameters = theta_bank
 
         figure, axes = pairplot(parameters.to("cpu").numpy())
 
