@@ -12,6 +12,8 @@ from sbi.utils.sbiutils import (
     handle_invalid_x,
     warn_on_invalid_x,
     x_shape_from_simulation,
+    get_data_since_round,
+    mask_sims_from_prior,
 )
 from sbi.utils.torchutils import (
     BoxUniform,
@@ -41,3 +43,4 @@ from sbi.utils.typechecks import (
 )
 
 from sbi.user_input.user_input_checks_utils import MultipleIndependent
+from sbi.user_input.user_input_checks import check_estimator_arg
