@@ -2,12 +2,12 @@
 # under the Affero General Public License v3, see <https://www.gnu.org/licenses/>.
 
 import logging
-from typing import Tuple, Dict, Sequence, Any
+from typing import Any, Dict, List, Sequence, Tuple
 
-from pyknos.nflows import transforms
 import torch
-from torch import Tensor, as_tensor, ones
 import torch.nn as nn
+from pyknos.nflows import transforms
+from torch import Tensor, as_tensor, ones, zeros
 from tqdm.auto import tqdm
 
 
@@ -61,6 +61,16 @@ def standardizing_transform(
     return transforms.AffineTransform(shift=-t_mean / t_std, scale=1 / t_std)
 
 
+class Standardize(nn.Module):
+    def __init__(self, mean, std):
+        super(Standardize, self).__init__()
+        self.mean = mean
+        self.std = std
+
+    def forward(self, tensor):
+        return (tensor - self.mean) / self.std
+
+
 def standardizing_net(batch_t: Tensor, min_std: float = 1e-7) -> nn.Module:
     """Builds standardizing network
 
@@ -74,15 +84,6 @@ def standardizing_net(batch_t: Tensor, min_std: float = 1e-7) -> nn.Module:
         Neural network module for z-scoring
     """
 
-    class Standardize(nn.Module):
-        def __init__(self, mean, std):
-            super(Standardize, self).__init__()
-            self.mean = mean
-            self.std = std
-
-        def forward(self, tensor):
-            return (tensor - self.mean) / self.std
-
     is_valid_t, *_ = handle_invalid_x(batch_t, True)
 
     t_mean = torch.mean(batch_t[is_valid_t], dim=0)
@@ -215,3 +216,36 @@ def warn_on_invalid_x(num_nans: int, num_infs: int, exclude_invalid_x: bool) ->
                 f"Found {num_nans} NaN simulations and {num_infs} Inf simulations. "
                 "Training might fail. Consider setting `exclude_invalid_x=True`."
             )
+
+
+def get_data_since_round(
+    data: List, data_round_indices: List, starting_round_index: int
+) -> Tensor:
+    """
+    Returns tensor with all data coming from a round >= `starting_round`.
+
+    Args:
+        data: Each list entry contains a set of data (either parameters, simulation
+            outputs, or prior masks).
+        data_round_indices: List with same length as data, each entry is an integer that
+            indicates which round the data is from.
+        starting_round_index: From which round onwards to return the data. We start
+            counting from 0.
+    """
+    return torch.cat(
+        [t for t, r in zip(data, data_round_indices) if r >= starting_round_index]
+    )
+
+
+def mask_sims_from_prior(round_: int, num_simulations: int) -> Tensor:
+    """Returns Tensor True where simulated from prior parameters.
+
+    Args:
+        round_: Current training round, starting at 0.
+        num_simulations: Actually performed simulations. This number can be below
+            the one fixed for the round if leakage correction through sampling is
+            active and `patience` is not enough to reach it.
+    """
+
+    prior_mask_values = ones if round_ == 0 else zeros
+    return prior_mask_values((num_simulations, 1), dtype=torch.bool)
