@@ -46,7 +46,7 @@ def test_api_snl_on_linearGaussian(num_dim: int, set_seed):
 
     posterior = infer(num_rounds=1, num_simulations_per_round=1000, max_num_epochs=5)
 
-    posterior.sample(sample_shape=(num_samples,), x=x_o, thin=3)
+    posterior.sample(sample_shape=(num_samples,), x=x_o, mcmc_parameters = {"thin": 3})
 
 
 def test_c2st_snl_on_linearGaussian_different_dims(set_seed):
@@ -98,12 +98,63 @@ def test_c2st_snl_on_linearGaussian_different_dims(set_seed):
     )
 
     posterior = infer(num_rounds=1, num_simulations_per_round=5000)  # type: ignore
-    samples = posterior.sample((num_samples,), x=x_o, thin=3)
+    samples = posterior.sample((num_samples,), x=x_o, mcmc_parameters = {"thin": 3})
 
     # Compute the c2st and assert it is near chance level of 0.5.
     check_c2st(samples, target_samples, alg="snle_a")
 
 
+@pytest.mark.slow
+def test_c2st_snle_external_data_on_linearGaussian(set_seed):
+    """Test whether SNPE C infers well a simple example with available ground truth.
+
+    Args:
+        set_seed: fixture for manual seeding
+    """
+
+    num_dim = 2
+
+    device = "cpu"
+    configure_default_device(device)
+    x_o = zeros(1, num_dim)
+    num_samples = 1000
+
+    # likelihood_mean will be likelihood_shift+theta
+    likelihood_shift = -1.0 * ones(num_dim)
+    likelihood_cov = 0.3 * eye(num_dim)
+
+    prior_mean = zeros(num_dim)
+    prior_cov = eye(num_dim)
+    prior = MultivariateNormal(loc=prior_mean, covariance_matrix=prior_cov)
+    gt_posterior = true_posterior_linear_gaussian_mvn_prior(
+        x_o[0], likelihood_shift, likelihood_cov, prior_mean, prior_cov
+    )
+    target_samples = gt_posterior.sample((num_samples,))
+
+    def simulator(theta):
+        return linear_gaussian(theta, likelihood_shift, likelihood_cov)
+
+    infer = SNL(
+        *prepare_for_sbi(simulator, prior),
+        simulation_batch_size=1000,
+        show_progress_bars=False,
+        device=device,
+    )
+
+    external_theta = prior.sample((1000,))
+    external_x = simulator(external_theta)
+
+    infer.provide_presimulated(external_theta, external_x)
+
+    posterior = infer(
+        num_rounds=1, num_simulations_per_round=1000, training_batch_size=100,
+    ).set_default_x(x_o)
+    samples = posterior.sample((num_samples,))
+
+    # Compute the c2st and assert it is near chance level of 0.5.
+    check_c2st(samples, target_samples, alg="snpe_c")
+
+
 @pytest.mark.slow
 @pytest.mark.parametrize("num_dim", (1, 2))
 @pytest.mark.parametrize("prior_str", ("uniform", "gaussian"))
@@ -147,7 +198,7 @@ def test_c2st_snl_on_linearGaussian(num_dim: int, prior_str: str, set_seed):
 
     posterior = infer(num_rounds=1, num_simulations_per_round=1000).set_default_x(x_o)
 
-    samples = posterior.sample(sample_shape=(num_samples,), thin=3)
+    samples = posterior.sample(sample_shape=(num_samples,), mcmc_parameters = {"thin": 3})
 
     # Check performance based on c2st accuracy.
     check_c2st(samples, target_samples, alg=f"snle_a-{prior_str}-prior")
@@ -197,7 +248,7 @@ def test_c2st_multi_round_snl_on_linearGaussian(set_seed):
 
     posterior = infer(num_rounds=2, x_o=x_o, num_simulations_per_round=500)
 
-    samples = posterior.sample(sample_shape=(num_samples,), thin=3)
+    samples = posterior.sample(sample_shape=(num_samples,), mcmc_parameters = {"thin": 3})
 
     # Check performance based on c2st accuracy.
     check_c2st(samples, target_samples, alg="multi-round-snl")
@@ -234,4 +285,4 @@ def test_api_snl_sampling_methods(mcmc_method: str, prior_str: str, set_seed):
 
     posterior = infer(num_rounds=1, num_simulations_per_round=200, max_num_epochs=5)
 
-    posterior.sample(sample_shape=(num_samples,), x=x_o, thin=3)
+    posterior.sample(sample_shape=(num_samples,), x=x_o, mcmc_parameters = {"thin": 3})
