@@ -171,6 +171,58 @@ def test_c2st_snpe_on_linearGaussian_different_dims(set_seed):
     check_c2st(samples, target_samples, alg="snpe_c")
 
 
+@pytest.mark.slow
+def test_c2st_snpe_external_data_on_linearGaussian(set_seed):
+    """Test whether SNPE C infers well a simple example with available ground truth.
+
+    Args:
+        set_seed: fixture for manual seeding
+    """
+
+    num_dim = 2
+
+    device = "cpu"
+    configure_default_device(device)
+    x_o = zeros(1, num_dim)
+    num_samples = 1000
+
+    # likelihood_mean will be likelihood_shift+theta
+    likelihood_shift = -1.0 * ones(num_dim)
+    likelihood_cov = 0.3 * eye(num_dim)
+
+    prior_mean = zeros(num_dim)
+    prior_cov = eye(num_dim)
+    prior = MultivariateNormal(loc=prior_mean, covariance_matrix=prior_cov)
+    gt_posterior = true_posterior_linear_gaussian_mvn_prior(
+        x_o[0], likelihood_shift, likelihood_cov, prior_mean, prior_cov
+    )
+    target_samples = gt_posterior.sample((num_samples,))
+
+    def simulator(theta):
+        return linear_gaussian(theta, likelihood_shift, likelihood_cov)
+
+    infer = SNPE_C(
+        *prepare_for_sbi(simulator, prior),
+        simulation_batch_size=1000,
+        show_progress_bars=False,
+        sample_with_mcmc=False,
+        device=device,
+    )
+
+    external_theta = prior.sample((1000,))
+    external_x = simulator(external_theta)
+
+    infer.provide_presimulated(external_theta, external_x)
+
+    posterior = infer(
+        num_rounds=1, num_simulations_per_round=1000, training_batch_size=100,
+    ).set_default_x(x_o)
+    samples = posterior.sample((num_samples,))
+
+    # Compute the c2st and assert it is near chance level of 0.5.
+    check_c2st(samples, target_samples, alg="snpe_c")
+
+
 # Test multi-round SNPE.
 @pytest.mark.slow
 @pytest.mark.parametrize(
